<template>
  <a-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    :okButtonProps="{ props: {disabled: disableSubmit} }"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">

        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="检验项目编号"
            >
              <a-input
                :disabled="disableSubmit"
                allow-clear
                placeholder="请输入检验项目编号"
                v-decorator="['itemCode', validatorRules.itemCode ]"
              />
            </a-form-item>
          </a-col>
        </a-row>

        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="检验项目名称"
            >
              <a-input
                :disabled="disableSubmit"
                allow-clear
                placeholder="请输入检验项目名称"
                v-decorator="['itemName', validatorRules.itemName ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
         <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="检验项目分类"
            >
              <j-dict-select-tag 
              :disabled="disableSubmit"
              placeholder="请输入检验项目分类"
              v-decorator="['itemCategory', validatorRules.itemCategory ]" 
              dictCode="item_category"/>
            </a-form-item>
          </a-col>
        </a-row>
         <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="定量/定性"
            >
              <j-dict-select-tag 
                :disabled="disableSubmit"
                placeholder="请选择定量/定性"
                v-decorator="['qualitativeOrQuantitative', validatorRules.qualitativeOrQuantitative ]"
                dictCode="qualitative_or_quantitative"/>
            </a-form-item>
          </a-col>
        </a-row>
         <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="测量工具"
            >
              <a-input
                :disabled="disableSubmit"
                allow-clear
                placeholder="请选择测量工具"
                v-decorator="['inspectionTools', validatorRules.inspectionTools ]"
              />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter="24">
          <a-col :span="24">
            <a-form-item
              :labelCol="labelCol" 
              :wrapperCol="wrapperCol"
              label="备注"
            >
            <a-textarea :disabled="disableSubmit" placeholder="请输入备注" v-decorator="['remark', validatorRules.remark ]"/>
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
  </a-modal>
</template>

<script>
import { httpAction, getAction } from '@/api/manage'
import pick from 'lodash.pick'
import { duplicateCheck } from '@/api/api'//重复校验

export default {
  name: "InspectionItemModal",
  data() {
    return {
      title: "操作",
      visible: false,
      disableSubmit: false,
      model: {},
      inspectionItemId: "", //保存检验项目id
      labelCol: {
          xs: { span: 24 },
          sm: { span: 5 },
        },
        wrapperCol: {
          xs: { span: 24 },
          sm: { span: 16 },
        },

      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        itemCode: {
          rules: [
            { required: true, message: '请输入检验项目编码' },
            { min: 2, max: 30, message: '长度在 2 到 30 个字符', trigger: 'blur' },
            { validator: this.validateNum },
          ]
        },
        itemName: {
          rules: [
            { required: true, message: '请输入检验项目名称' },
            { min: 0, max: 64, message: '长度不超过 64 个字符', trigger: 'blur' },
            { validator: this.validateName },
          ]
        },
      },
      url: {
        add: "/qms/inspectionItem/add",
        edit: "/qms/inspectionItem/edit",
      },
    }
  },
  created() {
  },
  methods: {
    add() {
      this.edit({});
    },
    edit(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.inspectionItemId = record.id;
      this.visible = true;
      this.$nextTick(() => {
        this.form.setFieldsValue(
          pick(this.model, 'itemCode', 'itemName','itemCategory','qualitativeOrQuantitative','inspectionTools', 'remark')
        )
      });
    },
    close() {
      this.$emit('close');
      this.visible = false;
    },
    handleOk() {
      const that = this;
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let httpurl = '';
          let method = '';
          if (!this.model.id) {
            httpurl += this.url.add;
            method = 'post';
          } else {
            httpurl += this.url.edit;
            method = 'put';
          }
          let formData = Object.assign(this.model, values);
          httpAction(httpurl, formData, method).then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },
    handleCancel() {
      this.close()
    },
    //验证 编号
    validateNum(rule, value, callback) {
      var params = {
        tableName: 'qms_inspection_item',
        fieldName: 'item_code',
        fieldVal: value,
        dataId: this.inspectionItemId,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: 'true',
      };
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback();
        } else {
          callback("检验项目编号已存在!");
        }
      })
    },
    //验证 名称
    validateName(rule, value, callback) {
      var params = {
        tableName: 'qms_inspection_items',
        fieldName: 'item_name',
        fieldVal: value,
        dataId: this.inspectionItemId,
        //数据库中存在字段del_flag并使用该字段作为未删除策略，真删除：false 假删除：true
        delFlag: 'true',
      };
      duplicateCheck(params).then((res) => {
        if (res.success) {
          callback();
        } else {
          callback("检验项目名称已存在!");
        }
      })
    },
    // 关闭弹窗时清除表单校验
    removeValidate() {
      if (this.$refs.form) this.$refs.form.clearValidate()
    }
  }
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>